@@ -1005,7 +1005,7 @@ Validate_comp_sprt_bnd <- function(alpha, beta, p0, p1, nmin, nmax) {
 #-------------------------------------------------------------------------------
 save_gg_plot <- function(code, width = 4, height = 4) {
   path <- tempfile(fileext = ".png")
-  ggsave(path, plot = code, width = width, height = height, dpi = 72, units = "in")
+  ggplot2::ggsave(path, plot = code, width = width, height = height, dpi = 72, units = "in")
   path
 }
 
